# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.character_advanced_config import CharacterAdvancedConfig  # noqa: E501

class TestCharacterAdvancedConfig(unittest.TestCase):
    """CharacterAdvancedConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CharacterAdvancedConfig:
        """Test CharacterAdvancedConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CharacterAdvancedConfig`
        """
        model = CharacterAdvancedConfig()  # noqa: E501
        if include_optional:
            return CharacterAdvancedConfig(
                repository_info = xingchen.models.repository_info.RepositoryInfo(
                    repository_files = [
                        xingchen.models.repository.Repository(
                            file_save_path = '', 
                            filename = '', 
                            file_url = '', 
                            status = '', )
                        ], 
                    status = '', ),
                is_real_info = True,
                search_keyword = '',
                allow_send_image = True,
                image_style = '',
                allow_send_asr = True,
                asr_style = '',
                chat_description = ''
            )
        else:
            return CharacterAdvancedConfig(
        )
        """

    def testCharacterAdvancedConfig(self):
        """Test CharacterAdvancedConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
