from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, StrictBool


class PlatformPlugin(BaseModel):
    enabled: Optional[StrictBool] = None
    name: Optional[StrictStr] = Field(None, alias="name")
    __properties = ["enabled", "name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlatformPlugin:
        """Create an instance of PlatformPlugin from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlatformPlugin:
        """Create an instance of PlatformPlugin from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlatformPlugin.parse_obj(obj)

        _obj = PlatformPlugin.parse_obj({
            "enabled": obj.get("enabled"),
            "name": obj.get("name")
        })
        return _obj
