# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from xingchen.api.character_api_sub import CharacterApiSub  # noqa: E501


class TestCharacterApiSub(unittest.TestCase):
    """CharacterApiSub unit test stubs"""

    def setUp(self) -> None:
        self.api = CharacterApiSub()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_character_details(self) -> None:
        """Test case for character_details

        角色详情  # noqa: E501
        """
        pass

    def test_character_details1(self) -> None:
        """Test case for character_details1

        角色详情  # noqa: E501
        """
        pass

    def test_create(self) -> None:
        """Test case for create

        创建角色  # noqa: E501
        """
        pass

    def test_create1(self) -> None:
        """Test case for create1

        创建角色  # noqa: E501
        """
        pass

    def test_create_or_update_version(self) -> None:
        """Test case for create_or_update_version

        创建或更新角色版本  # noqa: E501
        """
        pass

    def test_create_or_update_version1(self) -> None:
        """Test case for create_or_update_version1

        创建或更新角色版本  # noqa: E501
        """
        pass

    def test_delete(self) -> None:
        """Test case for delete

        删除角色  # noqa: E501
        """
        pass

    def test_delete1(self) -> None:
        """Test case for delete1

        删除角色  # noqa: E501
        """
        pass

    def test_list_character_versions(self) -> None:
        """Test case for list_character_versions

        角色版本列表  # noqa: E501
        """
        pass

    def test_list_character_versions1(self) -> None:
        """Test case for list_character_versions1

        角色版本列表  # noqa: E501
        """
        pass

    def test_recommend_character_version(self) -> None:
        """Test case for recommend_character_version

        角色版本列表  # noqa: E501
        """
        pass

    def test_recommend_character_version1(self) -> None:
        """Test case for recommend_character_version1

        角色版本列表  # noqa: E501
        """
        pass

    def test_search(self) -> None:
        """Test case for search

        查询角色  # noqa: E501
        """
        pass

    def test_search1(self) -> None:
        """Test case for search1

        查询角色  # noqa: E501
        """
        pass

    def test_update(self) -> None:
        """Test case for update

        更新角色信息  # noqa: E501
        """
        pass

    def test_update1(self) -> None:
        """Test case for update1

        更新角色信息  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
