# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.page_result_chat_message_dto import PageResultChatMessageDTO  # noqa: E501

class TestPageResultChatMessageDTO(unittest.TestCase):
    """PageResultChatMessageDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageResultChatMessageDTO:
        """Test PageResultChatMessageDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageResultChatMessageDTO`
        """
        model = PageResultChatMessageDTO()  # noqa: E501
        if include_optional:
            return PageResultChatMessageDTO(
                list = [
                    xingchen.models.chat_message_dto.ChatMessageDTO(
                        content = '', 
                        message_type = '', 
                        message_id = '', 
                        message_issuer = xingchen.models.chat_room_user_dto.ChatRoomUserDTO(
                            user_id = '', 
                            biz_user_id = '', 
                            user_name = '', 
                            user_type = '', ), 
                        session_id = '', 
                        chat_id = '', 
                        gmt_create = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_greeting = True, 
                        rating = 1.337, 
                        regenerate_times = 56, )
                    ],
                page = 56,
                page_size = 56,
                total = 56,
                page_offset_value = 56
            )
        else:
            return PageResultChatMessageDTO(
        )
        """

    def testPageResultChatMessageDTO(self):
        """Test PageResultChatMessageDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
