# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from xingchen.models.gateway_context import GatewayContext

class GatewayIssuedParams(BaseModel):
    """
    GatewayIssuedParams
    """
    user_info: Optional[Dict[str, StrictStr]] = Field(None, alias="userInfo")
    context: Optional[GatewayContext] = None
    __properties = ["userInfo", "context"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GatewayIssuedParams:
        """Create an instance of GatewayIssuedParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of context
        if self.context:
            _dict['context'] = self.context.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GatewayIssuedParams:
        """Create an instance of GatewayIssuedParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GatewayIssuedParams.parse_obj(obj)

        _obj = GatewayIssuedParams.parse_obj({
            "user_info": obj.get("userInfo"),
            "context": GatewayContext.from_dict(obj.get("context")) if obj.get("context") is not None else None
        })
        return _obj


