# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from xingchen.api.chat_message_api_sub import ChatMessageApiSub  # noqa: E501


class TestChatMessageApiSub(unittest.TestCase):
    """ChatMessageApiSub unit test stubs"""

    def setUp(self) -> None:
        self.api = ChatMessageApiSub()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_chat_histories(self) -> None:
        """Test case for chat_histories

        对话历史  # noqa: E501
        """
        pass

    def test_chat_histories1(self) -> None:
        """Test case for chat_histories1

        对话历史  # noqa: E501
        """
        pass

    def test_chat_histories2(self) -> None:
        """Test case for chat_histories2

        对话历史  # noqa: E501
        """
        pass

    def test_chat_histories3(self) -> None:
        """Test case for chat_histories3

        对话历史  # noqa: E501
        """
        pass

    def test_rate_message(self) -> None:
        """Test case for rate_message

        消息评分  # noqa: E501
        """
        pass

    def test_rate_message1(self) -> None:
        """Test case for rate_message1

        消息评分  # noqa: E501
        """
        pass

    def test_sys_reminder(self) -> None:
        """Test case for sys_reminder

        """
        pass

    def test_sys_reminder1(self) -> None:
        """Test case for sys_reminder1

        """
        pass


if __name__ == '__main__':
    unittest.main()
