# coding: utf-8

# flake8: noqa
"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from xingchen.models.advanced_settings import AdvancedSettings
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.character_advanced_config import CharacterAdvancedConfig
from xingchen.models.character_create_dto import CharacterCreateDTO
from xingchen.models.character_dto import CharacterDTO
from xingchen.models.character_key import CharacterKey
from xingchen.models.character_permission_config import CharacterPermissionConfig
from xingchen.models.character_query_dto import CharacterQueryDTO
from xingchen.models.character_query_where import CharacterQueryWhere
from xingchen.models.character_update_dto import CharacterUpdateDTO
from xingchen.models.character_version_create_or_update_dto import CharacterVersionCreateOrUpdateDTO
from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO
from xingchen.models.chat_history_query_where import ChatHistoryQueryWhere
from xingchen.models.chat_message_dto import ChatMessageDTO
from xingchen.models.chat_req_params import ChatReqParams
from xingchen.models.chat_room_user_dto import ChatRoomUserDTO
from xingchen.models.context import Context
from xingchen.models.file_info_vo import FileInfoVO
from xingchen.models.gateway_context import GatewayContext
from xingchen.models.gateway_issued_params import GatewayIssuedParams
from xingchen.models.input import Input
from xingchen.models.message import Message
from xingchen.models.message_rating_request import MessageRatingRequest
from xingchen.models.meta import Meta
from xingchen.models.model_parameters import ModelParameters
from xingchen.models.page_result_character_dto import PageResultCharacterDTO
from xingchen.models.page_result_chat_message_dto import PageResultChatMessageDTO
from xingchen.models.repository import Repository
from xingchen.models.repository_info import RepositoryInfo
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_character_dto import ResultDTOCharacterDTO
from xingchen.models.result_dto_character_key import ResultDTOCharacterKey
from xingchen.models.result_dto_list_character_dto import ResultDTOListCharacterDTO
from xingchen.models.result_dto_page_result_character_dto import ResultDTOPageResultCharacterDTO
from xingchen.models.result_dto_page_result_chat_message_dto import ResultDTOPageResultChatMessageDTO
from xingchen.models.scenario import Scenario
from xingchen.models.sys_reminder_request import SysReminderRequest
from xingchen.models.user_profile import UserProfile
from xingchen.models.result_dto_extract_summary_dto import ResultDTOExtractSummaryDTO
from xingchen.models.result_dto_extract_kv_dto import ResultDTOExtractKVDTO
from xingchen.models.result_dto_polling_image_detail_dto import ResultDTOPollingImageDetailDTO
from xingchen.models.result_dto_file_conver_dto import ResultDTOFileConvertDTO
from xingchen.models.result_dto_character_desc_dto import ResultDTOCharacterDescDTO
