# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.gateway_issued_params import GatewayIssuedParams  # noqa: E501

class TestGatewayIssuedParams(unittest.TestCase):
    """GatewayIssuedParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GatewayIssuedParams:
        """Test GatewayIssuedParams
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GatewayIssuedParams`
        """
        model = GatewayIssuedParams()  # noqa: E501
        if include_optional:
            return GatewayIssuedParams(
                user_info = {
                    'key' : ''
                    },
                context = xingchen.models.gateway_context.GatewayContext(
                    service_type = '', 
                    fc_url = '', 
                    flow_json_path = '', )
            )
        else:
            return GatewayIssuedParams(
        )
        """

    def testGatewayIssuedParams(self):
        """Test GatewayIssuedParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
