# coding: utf-8

# flake8: noqa

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.1.3"

# import apis into sdk package
from xingchen.api.character_api_sub import CharacterApiSub
from xingchen.api.chat_api_sub import ChatApiSub
from xingchen.api.chat_message_api_sub import ChatMessageApiSub
from xingchen.api.groupchat_api_sub import GroupChatApiSub
from xingchen.api.chat_extract_message_api_sub import ChatExtractMessageApiSub
from xingchen.api.common_api_sub import CommonApiSub

# import ApiClient
from xingchen.api_response import ApiResponse
from xingchen.api_client import ApiClient
from xingchen.configuration import Configuration
from xingchen.exceptions import OpenApiException
from xingchen.exceptions import ApiTypeError
from xingchen.exceptions import ApiValueError
from xingchen.exceptions import ApiKeyError
from xingchen.exceptions import ApiAttributeError
from xingchen.exceptions import ApiException

# import models into sdk package
from xingchen.models.advanced_settings import AdvancedSettings
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.character_advanced_config import CharacterAdvancedConfig
from xingchen.models.character_create_dto import CharacterCreateDTO
from xingchen.models.character_dto import CharacterDTO
from xingchen.models.character_key import CharacterKey
from xingchen.models.character_permission_config import CharacterPermissionConfig
from xingchen.models.character_query_dto import CharacterQueryDTO
from xingchen.models.character_query_where import CharacterQueryWhere
from xingchen.models.character_update_dto import CharacterUpdateDTO
from xingchen.models.character_version_create_or_update_dto import CharacterVersionCreateOrUpdateDTO
from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO
from xingchen.models.chat_history_query_where import ChatHistoryQueryWhere
from xingchen.models.chat_message_dto import ChatMessageDTO
from xingchen.models.chat_req_params import ChatReqParams
from xingchen.models.chat_room_user_dto import ChatRoomUserDTO
from xingchen.models.context import Context
from xingchen.models.file_info_vo import FileInfoVO
from xingchen.models.gateway_context import GatewayContext
from xingchen.models.gateway_issued_params import GatewayIssuedParams
from xingchen.models.input import Input
from xingchen.models.message import Message
from xingchen.models.message_rating_request import MessageRatingRequest
from xingchen.models.meta import Meta
from xingchen.models.model_parameters import ModelParameters
from xingchen.models.page_result_character_dto import PageResultCharacterDTO
from xingchen.models.page_result_chat_message_dto import PageResultChatMessageDTO
from xingchen.models.repository import Repository
from xingchen.models.repository_info import RepositoryInfo
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_character_dto import ResultDTOCharacterDTO
from xingchen.models.result_dto_character_key import ResultDTOCharacterKey
from xingchen.models.result_dto_list_character_dto import ResultDTOListCharacterDTO
from xingchen.models.result_dto_page_result_character_dto import ResultDTOPageResultCharacterDTO
from xingchen.models.result_dto_page_result_chat_message_dto import ResultDTOPageResultChatMessageDTO
from xingchen.models.scenario import Scenario
from xingchen.models.sys_reminder_request import SysReminderRequest
from xingchen.models.user_profile import UserProfile
from xingchen.models.chat_context import ChatContext
from xingchen.models.function_call import Function, FunctionChoice, FunctionCall, FunctionChoiceType, Plugin, \
    PlanningApiInfo
from xingchen.models.custom.reset_history_request import ResetChatHistoryRequest
from xingchen.models.custom.character_model_parameters import CharacterModelParameters
from xingchen.models.custom.platform_publish_config import PlatformPublishConfig
from xingchen.models.custom.groupchat.group_chat_reply_setting import GroupChatReplySetting
from xingchen.models.custom.groupchat.group_chat_room_info import GroupChatRoomInfo
from xingchen.models.custom.groupchat.group_chat_ext_param import GroupChatExtParam
from xingchen.models.extract_data import ExtractData
from xingchen.models.stop_chat_request import StopChatRequest
from xingchen.models.character_desc_generated_request import CharacterDescGeneratedRequest
from xingchen.models.keyword import Keyword
from xingchen.models.memory import Memory
from xingchen.models.kv_memory_config import KVMemoryConfig
from xingchen.models.long_term_memory import LongTermMemory
from xingchen.models.reject_answer_plugin import RejectAnswerPlugin
from xingchen.models.reject_condition import RejectCondition
from xingchen.models.text_to_image_plugin import TextToImagePlugin
from xingchen.models.platform_plugin import PlatformPlugin
from xingchen.models.extract_memory_request import ExtractMemoryRequest
from xingchen.models.extract_data import ExtractData
from xingchen.models.extract_kv_dto import ExtractKVDTO
from xingchen.models.extract_summary_dto import ExtractSummaryDTO
from xingchen.models.file_conver_dto import FileConvertDTO
from xingchen.models.file_conver_request import FileConvertRequest
from xingchen.models.memory_summary import MemorySummary
from xingchen.models.polling_image_detail_dto import PollingImageDetailDTO
from xingchen.models.result_dto_character_desc_dto import ResultDTOCharacterDescDTO
from xingchen.models.result_dto_file_conver_dto import ResultDTOFileConvertDTO
from xingchen.models.result_dto_polling_image_detail_dto import ResultDTOPollingImageDetailDTO
from xingchen.models.result_dto_extract_kv_dto import ResultDTOExtractKVDTO
from xingchen.models.result_dto_extract_summary_dto import ResultDTOExtractSummaryDTO

from xingchen.models.custom.completion.completion_req_function import AcAReqFunction
from xingchen.models.custom.completion.completion_resp_function import AcARespFunction
from xingchen.models.custom.completion.completion_usage import AcAUsage
from xingchen.models.custom.completion.completion_req_message import AcAReqMessage
from xingchen.models.custom.completion.completion_resp_message import AcARespMessage
from xingchen.models.custom.completion.completion_req_tool import AcAReqTool
from xingchen.models.custom.completion.completion_resp_tool import AcARespTool
from xingchen.models.custom.completion.completion_req import AcACompletionReq
from xingchen.models.custom.completion.completion_resp import AcACompletionResp
from xingchen.api.completion_api_sub import AcACompletionApiSub
