# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""

import re  # noqa: F401
from typing import Union, Generator

import requests
from pydantic import Field
from pydantic import validate_arguments
from sseclient import SSEClient
from typing_extensions import Annotated
from xingchen.api_response import ApiResponse
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.aca_util import convert_chat_params, handle_sse_response
from xingchen.api_client import ApiClient
from xingchen.exceptions import (
    ApiTypeError
)
from xingchen.models.chat_req_params import ChatReqParams
from xingchen.models.custom import ChatResponse
from xingchen.models.stop_chat_request import StopChatRequest


class ChatApiSub:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    def version(self):
        return self.api_client.api_version()

    @validate_arguments
    def chat(self, chat_req_params: Annotated[ChatReqParams, Field(..., description="对话请求")],
             **kwargs) -> Union[ChatResponse, Generator[ChatResponse, None, None]]:
        """用户对话  # noqa: E501

         发起角色对话：   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.chat(chat_req_params, async_req=True)
        >>> result = thread.get()

        :param chat_req_params: 对话请求 (required)
        :type chat_req_params: ChatReqParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the chat_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.chat_with_http_info(chat_req_params, **kwargs)  # noqa: E501

    @validate_arguments
    def chat_with_http_info(self, chat_req_params: Annotated[ChatReqParams, Field(..., description="对话请求")],
                            **kwargs) -> Union[ChatResponse, Generator[ChatResponse, None, None]]:  # noqa: E501
        """用户对话  # noqa: E501

         发起角色对话：   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.chat_with_http_info(chat_req_params, async_req=True)
        >>> result = thread.get()

        :param chat_req_params: 对话请求 (required)
        :type chat_req_params: ChatReqParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'chat_req_params'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method chat" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['chat_req_params'] is not None:
            _body_params = _params['chat_req_params']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/event-stream'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "object",
        }

        # 参数转化
        version = self.version()
        if not version or 'v2'.__eq__(version):
            _body_params = convert_chat_params(chat_req_params)
            if chat_req_params.streaming:
                _header_params['X-DashScope-SSE'] = 'enable'
                _header_params['X-AcA-SSE'] = 'enable'

        is_stream = chat_req_params.streaming \
                    or 'enable' == _header_params.get('X-DashScope-SSE') \
                    or 'enable' == _header_params.get('X-AcA-SSE')
        path = '/{0}/api/chat/send'.format(version)
        host = self.api_client.configuration.host

        if is_stream:
            _header_params['x-fag-appcode'] = 'aca'
            _header_params['x-fag-servicename'] = 'aca-chat-send-sse'
            _header_params['Authorization'] = 'Bearer ' + self.api_client.configuration.access_token
            body_params = self.api_client.sanitize_for_serialization(_body_params)

            request = requests.post(
                host + path,
                headers=_header_params,
                json=body_params,
                stream=True
            )
            client = SSEClient(request)
            return (res for res in handle_sse_response(client))

        response = self.api_client.call_api(
            '/{0}/api/chat/send'.format(version), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

        return ChatResponse.from_dict(response)

    @validate_arguments
    def stop_chat(self, stop_chat_request: Annotated[StopChatRequest, Field(..., description="停止对话请求")],
                  **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the stop_chat_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.stop_chat_with_http_info(stop_chat_request, **kwargs)  # noqa: E501

    @validate_arguments
    def stop_chat_with_http_info(self, stop_chat_request: Annotated[
        StopChatRequest, Field(..., description="停止对话请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'extract_memory_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method  stop_chat" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['stop_chat_request'] is not None:
            _body_params = _params['stop_chat_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/chat/stop'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
